summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--qt-ui/profilegraphics.cpp10
1 files changed, 7 insertions, 3 deletions
diff --git a/qt-ui/profilegraphics.cpp b/qt-ui/profilegraphics.cpp
index d2fa701f7..9e3db2d85 100644
--- a/qt-ui/profilegraphics.cpp
+++ b/qt-ui/profilegraphics.cpp
@@ -137,10 +137,12 @@ bool ProfileGraphicsView::eventFilter(QObject* obj, QEvent* event)
return true;
}
// This will "Eat" the default tooltip behavior.
if (event->type() == QEvent::GraphicsSceneHelp) {
- event->ignore();
- return true;
+ if(!toolBarProxy->geometry().contains(mapFromGlobal(QCursor::pos()))){
+ event->ignore();
+ return true;
+ }
}
return QGraphicsView::eventFilter(obj, event);
}
@@ -383,6 +385,8 @@ void ProfileGraphicsView::addControlItems(struct dive *d)
QAction *scaleAction = new QAction(QIcon(":scale"), tr("Scale"), this);
QAction *rulerAction = new QAction(QIcon(":ruler"), tr("Ruler"), this);
QToolBar *toolBar = new QToolBar("", 0);
+ rulerAction->setToolTip(tr("Show a ruler to nit pecking your dive"));
+ scaleAction->setToolTip(tr("Scale your dive to screen size"));
toolBar->addAction(rulerAction);
toolBar->addAction(scaleAction);
toolBar->setOrientation(Qt::Vertical);
@@ -137,10 +137,12 @@ bool ProfileGraphicsView::eventFilter(QObject* obj, QEvent* event)
return true;
}
- // This will "Eat" the default tooltip behavior.
+ // This will "Eat" the default tooltip behavior if it is not on the toolBar.
if (event->type() == QEvent::GraphicsSceneHelp) {